@@ -87,17 +87,21 @@ IrrecoBackendStatus read_string(
 	IRRECO_ENTER
 
 	if (ptr > 0) {
+		IRRECO_LINE
 		memmove(buffer, buffer + ptr, strlen(buffer + ptr) + 1);
 		ptr = strlen(buffer);
 		end = strchr(buffer, '\n');
 	} else {
+		IRRECO_LINE
 		end = NULL;
 	}
 
 	while (end == NULL) {
+		IRRECO_LINE
 		if (PACKET_SIZE <= ptr) {
 			ptr = 0;
 			*string = NULL;
+			IRRECO_LINE
 			IRRECO_RETURN_INT(internal_lirc_backend_error(
 				internal_lirc_backend,
 				INTERNAL_LIRC_BACKEND_ERR_BAD_PACKET));
@@ -106,14 +110,16 @@ IrrecoBackendStatus read_string(
 		if (input_timeout(internal_lirc_backend->socket, 3) < 1) {
 			ptr = 0;
 			*string = NULL;
+			IRRECO_LINE
 			IRRECO_RETURN_INT(internal_lirc_backend_error(
 				internal_lirc_backend,
 				INTERNAL_LIRC_BACKEND_ERR_TIMEOUT));;
 		} else {
+			IRRECO_LINE
 			ret = read(internal_lirc_backend->socket, buffer + ptr,
 				   PACKET_SIZE - ptr);
 		}
-
+		IRRECO_LINE
 		buffer[ptr + ret] = 0;
 		ptr = strlen(buffer);
 		end = strchr(buffer, '\n');
@@ -121,7 +127,7 @@ IrrecoBackendStatus read_string(
 
 	end[0] = 0;
 	ptr = strlen(buffer) + 1;
-	IRRECO_DEBUG("Input buffer \"%s\".\n", buffer);
+	IRRECO_PRINTF("Input buffer \"%s\".\n", buffer);
 	*string = buffer;
 	IRRECO_RETURN_INT(IRRECO_BACKEND_OK);
 }
@@ -153,9 +159,11 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 
 	todo = strlen(packet);
 	data = packet;
+	IRRECO_PRINTF("todo: %d   data: %s\n", todo, data);
 	while (todo > 0) {
 		done = write(internal_lirc_backend->socket, (void *) data, todo);
 		if (done < 0) {
+			IRRECO_LINE
 			IRRECO_RETURN_INT(internal_lirc_backend_error(
 						internal_lirc_backend,
 				INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_SEND_PACKET,
@@ -163,6 +171,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 		}
 		data += done;
 		todo -= done;
+		IRRECO_PRINTF("inwhile todo: %d  data: %s\n", todo, data);
 	}
 
 	/* get response */
@@ -170,15 +179,17 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 	state = P_BEGIN;
 	n = 0;
 	while (1) {
-
+		IRRECO_LINE
 		read_string_status = read_string(internal_lirc_backend,
 							&string);
 		if (read_string_status != IRRECO_BACKEND_OK) {
+			IRRECO_LINE
 			IRRECO_RETURN_INT(read_string_status);
 		}
-
+		IRRECO_LINE
 		switch (state) {
 		case P_BEGIN:
+			IRRECO_LINE
 			if (strcasecmp(string, "BEGIN") != 0) {
 				continue;
 			}
@@ -186,6 +197,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			break;
 
 		case P_MESSAGE:
+			IRRECO_LINE
 			if (strncasecmp(string, packet, strlen(string)) != 0 ||
 			    strlen(string) + 1 != strlen(packet)) {
 				state = P_BEGIN;
@@ -195,6 +207,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			break;
 
 		case P_STATUS:
+			IRRECO_LINE
 			if (strcasecmp(string, "SUCCESS") == 0) {
 				status = 0;
 			} else if (strcasecmp(string, "END") == 0) {
@@ -210,6 +223,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			break;
 
 		case P_DATA:
+			IRRECO_LINE
 			if (strcasecmp(string, "END") == 0) {
 				goto check_status_code;
 			} else if (strcasecmp(string, "DATA") == 0) {
@@ -220,6 +234,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			goto check_status_code;
 
 		case P_N:
+			IRRECO_LINE
 			errno = 0;
 			data_n = strtoul(string, &endptr, 0);
 			if (!*string || *endptr) {
@@ -234,6 +249,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			break;
 
 		case P_DATA_N:
+			IRRECO_LINE
 			IRRECO_DEBUG("Response data: \"%s\".\n", string);
 			if (handler != NULL) handler(internal_lirc_backend, string);
 			n++;
@@ -241,6 +257,7 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 			break;
 
 		case P_END:
+			IRRECO_LINE
 			if (strcasecmp(string, "END") == 0) {
 				goto check_status_code;
 			}
@@ -252,20 +269,26 @@ IrrecoBackendStatus send_packet(IrrecoInternalLircBackend * internal_lirc_backen
 
 	check_status_code:
 	switch (status) {
+		IRRECO_LINE
 	case INTERNAL_LIRC_BACKEND_ERR_BAD_PACKET:
+		IRRECO_LINE
 		IRRECO_RETURN_INT(internal_lirc_backend_error(
 			internal_lirc_backend,
 			INTERNAL_LIRC_BACKEND_ERR_BAD_PACKET));
 
 	case INTERNAL_LIRC_BACKEND_ERR_COMMAND_FAILED:
+		IRRECO_LINE
 		IRRECO_RETURN_INT(internal_lirc_backend_error(
 			internal_lirc_backend,
 			INTERNAL_LIRC_BACKEND_ERR_COMMAND_FAILED, packet));
 
 	case IRRECO_BACKEND_OK:
+		IRRECO_LINE
 		IRRECO_RETURN_INT(IRRECO_BACKEND_OK);
 
 	default:
+		IRRECO_LINE
+		IRRECO_PRINTF("Weird return code \"%d\"\n", status);
 		IRRECO_ERROR("Weird return code \"%i\"\n", status);
 		IRRECO_RETURN_INT(status);
 	}
@@ -321,25 +344,30 @@ static IrrecoBackendStatus internal_lirc_delete_device(
 		"sed -e \'s/^include.*", device_name,
 		INTERNAL_LIRC_LIRCD_CONF_PATH,
 		INTERNAL_LIRC_LIRCD_CONF_PATH);
-
+	IRRECO_LINE
+	IRRECO_PRINTF("%s\n", delete_cmd);
 	system(delete_cmd);
 
 	switch(status) {
 		case IRRECO_BACKEND_OK:
+			IRRECO_LINE
 			IRRECO_RETURN_INT(IRRECO_BACKEND_OK);
 
 		case INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_DELETE_DEVICE:
+			IRRECO_LINE
 			IRRECO_RETURN_INT(
 			INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_DELETE_DEVICE);
 
 		default:
-			IRRECO_ERROR("Weird return code \"%i\"\n", status);
+			IRRECO_LINE
+			IRRECO_PRINTF("Weird return code \"%d\"\n", status);
 			IRRECO_RETURN_INT(status);
 	}
 	g_free(delete_cmd);
 
 	/* TODO Just testing FIXME */
 	if(!status) {
+		IRRECO_LINE
 		g_print("errmsg: %s\n", internal_lirc_backend->error_msg->str);
 		IRRECO_RETURN_INT(
 			INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_DELETE_DEVICE);
@@ -362,12 +390,16 @@ IrrecoBackendStatus internal_lirc_export_conf(gpointer instance_context,
 	g_string_append_printf(file_name, "%s", device_name);
 	g_string_append_printf(file_path, "/%s", file_name->str);
 
+	IRRECO_LINE
+	IRRECO_PRINTF("%s, %s, %s\n", device_name, file_name->str, file_path->str);
+
 	success = g_file_get_contents(file_path->str, &file_data, NULL, NULL);
 	if (success == FALSE) {
+		IRRECO_LINE
 		status = INTERNAL_LIRC_BACKEND_ERR_FILE_OPEN_FAILED;
 		goto clean;
 	}
-
+	IRRECO_LINE
 	*file_container = irreco_backend_file_container_new();
 	irreco_backend_file_container_set(*file_container,
 					  "Internal Lirc",	/*backend*/
@@ -396,40 +428,44 @@ IrrecoBackendStatus internal_lirc_import_conf(gpointer instance_context,
 	length = strlen(file_container->data->str);
 
 	g_string_append_printf(file_path, "/%s", file_container->name->str);
-
+	IRRECO_PRINTF("%s\n", file_path->str);
 	/* Create directory/directories for Lirc devices, if needed. */
 	if(irreco_is_dir(INTERNAL_LIRC_BASE_DIR) == FALSE) {
+		IRRECO_LINE
 		if (g_mkdir(INTERNAL_LIRC_BASE_DIR, 0700) != 0) {
+			IRRECO_LINE
 			IRRECO_RETURN_ENUM(
 			INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_CREATE_BASE_DIR);
 		}
 	}
-
+	IRRECO_LINE
 	if(irreco_is_dir(INTERNAL_LIRC_REMOTES_DIR) == FALSE) {
+		IRRECO_LINE
 		if (g_mkdir(INTERNAL_LIRC_REMOTES_DIR, 0700) != 0) {
+			IRRECO_LINE
 			IRRECO_RETURN_ENUM(
 			INTERNAL_LIRC_BACKEND_ERR_COULD_NOT_CREATE_DEVICE_DIR);
 		}
 	}
-
+	IRRECO_LINE
 	/* irreco_write_file from irreco_util.h */
 	success = irreco_write_file(file_path->str,
 				    file_container->data->str, length);
-
+	IRRECO_LINE
 	/* Echo include cmd to lircd.conf */
 	sys_cmd = g_strdup_printf("%s '%s \"%s\"' >> %s", "echo", "include",
 				file_path->str, INTERNAL_LIRC_LIRCD_CONF_PATH);
-
+	IRRECO_PRINTF("%s\n", sys_cmd);
 	system(sys_cmd);
 
 	g_string_free(file_path, TRUE);
 	g_free(sys_cmd);
 
 	if(!success){
-
+		IRRECO_LINE
 		IRRECO_RETURN_ENUM(INTERNAL_LIRC_BACKEND_ERR_CONFIG_WRITE_FAILED);
 	}
-
+	IRRECO_LINE
 	IRRECO_RETURN_ENUM(IRRECO_BACKEND_OK);
 }
 
@@ -600,11 +636,13 @@ gint internal_lirc_backend_error(IrrecoInternalLircBackend
 		break;
 
 	default:
+		IRRECO_LINE
 		g_string_set_size(internal_lirc_backend->error_msg, 0);
 		g_string_append_printf(internal_lirc_backend->error_msg,
 				       _("Unknown error code \"%i\"."), code);
 		IRRECO_PRINTF("Error: %s\n",
 				internal_lirc_backend->error_msg->str);
+		IRRECO_LINE
 		IRRECO_RETURN_INT(code);
 		break;
 	}
@@ -616,7 +654,7 @@ gint internal_lirc_backend_error(IrrecoInternalLircBackend
 	g_string_set_size(internal_lirc_backend->error_msg, 0);
 	g_string_append(internal_lirc_backend->error_msg, message);
 	g_free(message);
-
+	IRRECO_LINE
 	/* Print error and return code. */
 	IRRECO_PRINTF("Error: %s\n", internal_lirc_backend->error_msg->str);
 	IRRECO_RETURN_INT(code);
@@ -639,21 +677,25 @@ IrrecoBackendStatus internal_lirc_backend_read_from_conf(
 	IrrecoInternalLircBackend * internal_lirc_backend = instance_context;
 	IRRECO_ENTER
 
-	IRRECO_DEBUG("Reading config file \"%s\".\n", config_file);
+	IRRECO_PRINTF("Reading config file \"%s\".\n", config_file);
 	dir = g_path_get_dirname(config_file);
+	IRRECO_PRINTF("dir: %s\n", dir);
 	keyfile = irreco_keyfile_create(dir, config_file, "internal_lirc");
+	IRRECO_PRINTF("%s, %s, %s\n", keyfile->file, keyfile->dir, keyfile->group);
 
 	/* Attempt to read values from keyfile. */
 	if (keyfile == NULL
 	    || irreco_keyfile_get_int(keyfile, "port", &port) == FALSE
 	    || irreco_keyfile_get_str(keyfile, "host", &host) == FALSE) {
 		IRRECO_PRINTF("Config read failed\n");
+		IRRECO_LINE
 		rvalue = internal_lirc_backend_error(
 				internal_lirc_backend,
 				INTERNAL_LIRC_BACKEND_ERR_CONFIG_READ_FAILED);
 
 	/* Save values to instace if read succeeded. */
 	} else {
+		IRRECO_LINE
 		IRRECO_PRINTF("Host \"%s\"\n", host);
 		IRRECO_PRINTF("Port \"%i\"\n", port);
 
@@ -681,7 +723,7 @@ IrrecoBackendStatus internal_lirc_backend_save_to_conf(
 	IrrecoInternalLircBackend * internal_lirc_backend = instance_context;
 	IRRECO_ENTER
 
-	IRRECO_DEBUG("Saving config file \"%s\".\n", config_file);
+	IRRECO_PRINTF("Saving config file \"%s\".\n", config_file);
 
 	keyfile = g_key_file_new();
 	g_key_file_set_string(keyfile, group, "host",
@@ -693,8 +735,10 @@ IrrecoBackendStatus internal_lirc_backend_save_to_conf(
 	g_key_file_free(keyfile);
 
 	if (success == TRUE) {
+		IRRECO_LINE
 		IRRECO_RETURN_INT(IRRECO_BACKEND_OK);
 	}
+	IRRECO_LINE
 	IRRECO_RETURN_INT(internal_lirc_backend_error(
 		internal_lirc_backend,
 		INTERNAL_LIRC_BACKEND_ERR_CONFIG_WRITE_FAILED));
@@ -900,14 +944,16 @@ IrrecoBackendStatus internal_lirc_backend_send_command(gpointer instance_context
 
 	rvalue = internal_lirc_backend_connect(internal_lirc_backend);
 	if (rvalue) IRRECO_RETURN_INT(rvalue);
-
+	IRRECO_LINE
 	packet = g_string_new(NULL);
 	g_string_append_printf(packet, "SEND_ONCE %s %s\n",
 			       device_name, command_name);
+	IRRECO_PRINTF("%s\n", packet->str);
+	IRRECO_LINE
 	rvalue = send_packet(internal_lirc_backend, packet->str, NULL);
 	g_string_free(packet, TRUE);
 	if (rvalue) IRRECO_RETURN_INT(rvalue);
-
+	IRRECO_LINE
 	internal_lirc_backend_disconnect(internal_lirc_backend);
 	IRRECO_RETURN_INT(IRRECO_BACKEND_OK);
 }
